<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AddRecording</name>
    <message>
        <source>Schedule a:</source>
        <translation>Rozvrhnout:</translation>
    </message>
    <message>
        <source>&amp;Recording</source>
        <translation>&amp;Nahrávat</translation>
    </message>
    <message>
        <source>&amp;Playout</source>
        <translation>&amp;Přehrávat</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Stáhnout</translation>
    </message>
    <message>
        <source>&amp;Upload</source>
        <translation>&amp;Nahrát</translation>
    </message>
    <message>
        <source>&amp;Macro Cart</source>
        <translation>&amp;Makro vozík</translation>
    </message>
    <message>
        <source>&amp;Switch Event</source>
        <translation>Událost &amp;přepnutí</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
</context>
<context>
    <name>CatchListView</name>
    <message>
        <source>Edit Cue Markers</source>
        <translation>&amp;Upravit značky CUE</translation>
    </message>
</context>
<context>
    <name>DeckMon</name>
    <message>
        <source>MON</source>
        <translation>MON</translation>
    </message>
    <message>
        <source>ABORT</source>
        <translation>ZRUŠIT</translation>
    </message>
    <message>
        <source>OFFLINE</source>
        <translation>NEPŘIPOJENÝ</translation>
    </message>
    <message>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <source>R</source>
        <translation>P</translation>
    </message>
    <message>
        <source>IDLE</source>
        <translation>NEČINNÝ</translation>
    </message>
    <message>
        <source>READY</source>
        <translation>PŘIPRAVENÝ</translation>
    </message>
    <message>
        <source>WAITING</source>
        <translation>ČEKÁNÍ</translation>
    </message>
    <message>
        <source>RECORDING</source>
        <translation>NAHRÁVÁNÍ</translation>
    </message>
    <message>
        <source>PLAYING</source>
        <translation>PŘEHRÁVÁNÍ</translation>
    </message>
    <message>
        <source>[multiple events]</source>
        <translation>[více událostí]</translation>
    </message>
    <message>
        <source>[unknown cut]</source>
        <translation>[neznámý záběr]</translation>
    </message>
    <message>
        <source>[no description]</source>
        <translation>[bez popisu]</translation>
    </message>
</context>
<context>
    <name>EditCartEvent</name>
    <message>
        <source>Edit Cart Event</source>
        <translation>Upravit událost vozíku</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Událost činná</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Umístění:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Počáteční čas:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <source>Cart Number:</source>
        <translation>Číslo vozíku:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vybrat</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Činné dny</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Pondělí</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Úterý</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Středa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Čtvrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Pátek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Neděle</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Jen jednou</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Uložit jako
nové</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Zdvojená událost</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Událost s těmito parametry již existuje!</translation>
    </message>
    <message>
        <source>Invalid Cart</source>
        <translation>Neplatný vozík</translation>
    </message>
    <message>
        <source>That cart doesn&apos;t exist!</source>
        <translation>Vozík neexistuje!</translation>
    </message>
</context>
<context>
    <name>EditDownload</name>
    <message>
        <source>Edit Download</source>
        <translation>Upravit stahování</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Událost činná</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Umístění:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Počáteční čas:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <source>Url:</source>
        <translation>Adresa (URL):</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Uživatelské jméno:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Cíl:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vybrat</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Kanály:</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Automatické zastřižení</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Úroveň:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dbFS</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizovat</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Činné dny</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Pondělí</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Úterý</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Středa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Čtvrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Pátek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Neděle</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Jen jednou</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Uložit jako
nové</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Zdvojená událost</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Událost s těmito parametry již existuje!</translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation>Neplatná adresa (URL)</translation>
    </message>
    <message>
        <source>The URL is invalid!</source>
        <translation>Adresa je neplatná!</translation>
    </message>
    <message>
        <source>Unsupported URL protocol!</source>
        <translation>Nepodporovaný protokol URL!</translation>
    </message>
    <message>
        <source>Event Offset:</source>
        <translation>Posun události:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dny</translation>
    </message>
    <message>
        <source>Missing Username</source>
        <translation>Chybí uživatelské jméno</translation>
    </message>
    <message>
        <source>You must specify a username!</source>
        <translation>Musíte zadat uživatelské jméno!</translation>
    </message>
    <message>
        <source>Update Library Metadata</source>
        <translation>Obnovit knihovní popisná data</translation>
    </message>
</context>
<context>
    <name>EditPlayout</name>
    <message>
        <source>Edit Playout</source>
        <translation>Upravit přehrávání</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Událost činná</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Umístění:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Počáteční čas:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Cíl:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vybrat</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Činné dny</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Pondělí</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Úterý</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Středa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Čtvrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Pátek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Neděle</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Jen jednou</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Uložit jako
nové</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation type="obsolete">Zdvojená událost</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation type="obsolete">Událost s těmito parametry již existuje!</translation>
    </message>
</context>
<context>
    <name>EditRecording</name>
    <message>
        <source>Edit Recording</source>
        <translation>Upravit nahrávání</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Událost činná</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Umístění:</translation>
    </message>
    <message>
        <source>Start Parameters</source>
        <translation>Počáteční parametry</translation>
    </message>
    <message>
        <source>Use Hard Time</source>
        <translation>Použít pevný čas</translation>
    </message>
    <message>
        <source>Record Start Time:</source>
        <translation>Počáteční čas nahrávání:</translation>
    </message>
    <message>
        <source>Use GPI</source>
        <translation>Použít GPI</translation>
    </message>
    <message>
        <source>Window Start Time:</source>
        <translation>Počáteční čas okna:</translation>
    </message>
    <message>
        <source>GPI Matrix:</source>
        <translation>Matice GPI:</translation>
    </message>
    <message>
        <source>GPI Line:</source>
        <translation>Řádek GPI:</translation>
    </message>
    <message>
        <source>Start Delay:</source>
        <translation>Zpoždění začátku:</translation>
    </message>
    <message>
        <source>Allow Multiple Recordings within this Window</source>
        <translation>Dovolit v tomto okně více nahrávek</translation>
    </message>
    <message>
        <source>End Parameters</source>
        <translation>Koncové parametry</translation>
    </message>
    <message>
        <source>Use Length</source>
        <translation>Použít délku</translation>
    </message>
    <message>
        <source>Record Length:</source>
        <translation>Délka nahrávání:</translation>
    </message>
    <message>
        <source>Record End Time:</source>
        <translation>Koncový čas nahrávání:</translation>
    </message>
    <message>
        <source>Window End Time:</source>
        <translation>Koncový čas okna:</translation>
    </message>
    <message>
        <source>Max Record Length:</source>
        <translation>Největší délka nahrávání:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <source>Source:</source>
        <translation>Zdroj:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Cíl:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vybrat</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Kanály:</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Automatické zastřižení</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Úroveň:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dbFS</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizovat</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Činné dny</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Pondělí</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Úterý</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Středa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Čtvrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Pátek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Neděle</translation>
    </message>
    <message>
        <source>Start Date Offset:</source>
        <translation>Posun počátečního data:</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádný</translation>
    </message>
    <message>
        <source>End Date Offset:</source>
        <translation>Posun koncového data:</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Jen jednou</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Uložit jako
nové</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <source>Missing Cut</source>
        <translation>Chybí záběr</translation>
    </message>
    <message>
        <source>You must assign a record cut!</source>
        <translation>Musíte vybrat záběr nahrávání!</translation>
    </message>
    <message>
        <source>Record Parameter Error</source>
        <translation>Chyba v parametru nahrávání</translation>
    </message>
    <message>
        <source>The start GPI window cannot end before it begins!</source>
        <translation>Počáteční okno GPI nemůže skončit předtím, než začne!</translation>
    </message>
    <message>
        <source>The recording cannot end before it begins!</source>
        <translation>Nahrávání nemůže skončit předtím, než začne!</translation>
    </message>
    <message>
        <source>The end GPI window cannot end before it begins!</source>
        <translation>Koncové okno GPI nemůže skončit předtím, než začne!</translation>
    </message>
    <message>
        <source>The start GPI matrix doesn&apos;t exist!</source>
        <translation>Počáteční matice GPI neexistuje!</translation>
    </message>
    <message>
        <source>The start GPI line doesn&apos;t exist!</source>
        <translation>Počáteční řádek GPI neexistuje!</translation>
    </message>
    <message>
        <source>The end GPI matrix doesn&apos;t exist!</source>
        <translation>Koncová matice GPI neexistuje!</translation>
    </message>
    <message>
        <source>The end GPI line doesn&apos;t exist!</source>
        <translation>Koncový řádek GPI neexistuje!</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Zdvojená událost</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Událost s těmito parametry již existuje!</translation>
    </message>
</context>
<context>
    <name>EditSwitchEvent</name>
    <message>
        <source>Edit Switcher Event</source>
        <translation>Upravit událost přepínače</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Událost činná</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Umístění:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Počáteční čas:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <source>Switch Matrix:</source>
        <translation>Matice přepnutí:</translation>
    </message>
    <message>
        <source>Switch Input:</source>
        <translation>Vstup přepnutí:</translation>
    </message>
    <message>
        <source>Switch Output:</source>
        <translation>Výstup přepnutí:</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Činné dny</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Pondělí</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Úterý</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Středa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Čtvrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Pátek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Neděle</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Jen jednou</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Uložit jako
nové</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>--OFF--</source>
        <translation>--VYPNUTO--</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Zdvojená událost</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Událost s těmito parametry již existuje!</translation>
    </message>
</context>
<context>
    <name>EditUpload</name>
    <message>
        <source>Edit Upload</source>
        <translation>Upravit nahrání</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Událost činná</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Umístění:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Počáteční čas:</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[žádný]</translation>
    </message>
    <message>
        <source>RSS Feed:</source>
        <translation>Přívod RSS:</translation>
    </message>
    <message>
        <source>Source:</source>
        <translation>Zdroj:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vybrat</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <source>Url:</source>
        <translation>Adresa (URL):</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Uživatelské jméno:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Export Format:</source>
        <translation>Formát vyvedení:</translation>
    </message>
    <message>
        <source>S&amp;et</source>
        <translation>&amp;Nastavit</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizovat</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Úroveň:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dbFS</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Činné dny</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Pondělí</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Úterý</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Středa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Čtvrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Pátek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Neděle</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Jen jednou</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Uložit jako
nové</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Unsupported Format</source>
        <translation>Nepodporovaný formát</translation>
    </message>
    <message>
        <source>The currently selected export format is unsupported on this host!</source>
        <translation>Nyní vybraný formát vyvedení není tímto serverem podporován!</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Zdvojená událost</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Událost s těmito parametry již existuje!</translation>
    </message>
    <message>
        <source>The currently selected export format is unsupported on host </source>
        <translation>Nyní vybraný formát vyvedení není podporován serverem </translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation>Neplatná adresa (URL)</translation>
    </message>
    <message>
        <source>The URL is invalid!</source>
        <translation>Adresa je neplatná!</translation>
    </message>
    <message>
        <source>Unsupported URL protocol!</source>
        <translation>Nepodporovaný protokol URL!</translation>
    </message>
    <message>
        <source>Event Offset:</source>
        <translation>Posun události:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dny</translation>
    </message>
    <message>
        <source>Missing Username</source>
        <translation>Chybí uživatelské jméno</translation>
    </message>
    <message>
        <source>You must specify a username!</source>
        <translation>Musíte zadat uživatelské jméno!</translation>
    </message>
    <message>
        <source>Export Library Metadata</source>
        <translation>Vyvést knihovní popisná data</translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>RDLibrary Reports</source>
        <translation>Zprávy RDLibrary</translation>
    </message>
    <message>
        <source>Event Report</source>
        <translation>Zpráva o události</translation>
    </message>
    <message>
        <source>Upload/Download Report</source>
        <translation>Nahrát/Stáhnout zprávu</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation>Vy&amp;tvořit:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCatch - Host:</source>
        <translation type="obsolete">RDCatch - Server:</translation>
    </message>
    <message>
        <source>rdcatch : </source>
        <translation type="obsolete">rdcatch: </translation>
    </message>
    <message>
        <source>Show Only Active Events</source>
        <translation>Ukázat pouze činné události</translation>
    </message>
    <message>
        <source>Show Only Today&apos;s Events</source>
        <translation>Ukázat pouze dnešní události</translation>
    </message>
    <message>
        <source>Show DayOfWeek:</source>
        <translation>Ukázat dny v týdnu:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Dny v týdnu</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Neděle</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Pondělí</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Úterý</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Středa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Čtvrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Pátek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">POPIS</translation>
    </message>
    <message>
        <source>LOCATION</source>
        <translation type="obsolete">UMÍSTĚNÍ</translation>
    </message>
    <message>
        <source>START</source>
        <translation type="obsolete">ZAČÁTEK</translation>
    </message>
    <message>
        <source>END</source>
        <translation type="obsolete">KONEC</translation>
    </message>
    <message>
        <source>SOURCE</source>
        <translation type="obsolete">ZDROJ</translation>
    </message>
    <message>
        <source>DESTINATION</source>
        <translation type="obsolete">CÍL</translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation type="obsolete">PŮVOD</translation>
    </message>
    <message>
        <source>ONE SHOT</source>
        <translation type="obsolete">JEDNOU</translation>
    </message>
    <message>
        <source>TRIM THRESHOLD</source>
        <translation type="obsolete">PRÁH ZASTŘIŽENÍ</translation>
    </message>
    <message>
        <source>STARTDATE OFFSET</source>
        <translation type="obsolete">POSUN POČÁTEČNÍHO DATA</translation>
    </message>
    <message>
        <source>ENDDATE OFFSET</source>
        <translation type="obsolete">POSUN KONCOVÉHO DATA</translation>
    </message>
    <message>
        <source>FORMAT</source>
        <translation type="obsolete">FORMÁT</translation>
    </message>
    <message>
        <source>CHANNELS</source>
        <translation type="obsolete">KANÁLY</translation>
    </message>
    <message>
        <source>SAMPLE RATE</source>
        <translation type="obsolete">VZORKOVACÍ KMITOČET</translation>
    </message>
    <message>
        <source>BIT RATE</source>
        <translation type="obsolete">DATOVÝ TOK</translation>
    </message>
    <message>
        <source>STATION</source>
        <translation type="obsolete">STANICE</translation>
    </message>
    <message>
        <source>DECK</source>
        <translation type="obsolete">PATRO</translation>
    </message>
    <message>
        <source>CUT</source>
        <translation type="obsolete">ZÁBĚR</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="obsolete">VOZÍK</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="obsolete">TYP</translation>
    </message>
    <message>
        <source>STATUS</source>
        <translation type="obsolete">STAV</translation>
    </message>
    <message>
        <source>EXIT CODE</source>
        <translation type="obsolete">UKONČOVACÍ KÓD</translation>
    </message>
    <message>
        <source>STATE</source>
        <translation type="obsolete">STAV</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Přidat</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Upravit</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>S&amp;mazat</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Projíždět</translation>
    </message>
    <message>
        <source>Reports</source>
        <translation>Zprávy</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Událost činná</translation>
    </message>
    <message>
        <source>You cannot edit an active event!</source>
        <translation>Nemůžete upravovat činnou událost!</translation>
    </message>
    <message>
        <source>Are you sure you want to delete event</source>
        <translation>Jste si jistý, že chcete smazat událost</translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation>Smazat událost</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Nelze spojit</translation>
    </message>
    <message>
        <source>Unable to connect to Core AudioEngine</source>
        <translation>Spojení s Core AudioEngine se nezdařilo</translation>
    </message>
    <message>
        <source>Control connection timed out to host</source>
        <translation>Kontrolní spojení k serveru vypršelo</translation>
    </message>
    <message>
        <source>Su</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>Mo</source>
        <translation>Po</translation>
    </message>
    <message>
        <source>Tu</source>
        <translation>Út</translation>
    </message>
    <message>
        <source>We</source>
        <translation>St</translation>
    </message>
    <message>
        <source>Th</source>
        <translation>Čt</translation>
    </message>
    <message>
        <source>Fr</source>
        <translation>Pá</translation>
    </message>
    <message>
        <source>Sa</source>
        <translation>So</translation>
    </message>
    <message>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <source>Hard</source>
        <translation>Ostré</translation>
    </message>
    <message>
        <source>Gpi</source>
        <translation>GPI</translation>
    </message>
    <message>
        <source>Len</source>
        <translation>Délka</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Záběr</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation>PCM16</translation>
    </message>
    <message>
        <source>MPEG Layer 1</source>
        <translation>MPEG Layer 1</translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation>MPEG Layer 2</translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation>MPEG Layer 3</translation>
    </message>
    <message>
        <source>FLAC</source>
        <translation>FLAC</translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation>OggVorbis</translation>
    </message>
    <message>
        <source>Cart</source>
        <translation>Vozík</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[žádný]</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>Short Length</source>
        <translation type="obsolete">Kurze Länge</translation>
    </message>
    <message>
        <source>Low Level</source>
        <translation type="obsolete">Niedriges Level</translation>
    </message>
    <message>
        <source>High Level</source>
        <translation type="obsolete">Hohes Level</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">Herunterladen</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation type="obsolete">Hochladen</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation type="obsolete">Aufnehmen</translation>
    </message>
    <message>
        <source>Playing</source>
        <translation type="obsolete">Abspielen</translation>
    </message>
    <message>
        <source>Waiting</source>
        <translation type="obsolete">Warten</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation type="obsolete">Serverfehler</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="obsolete">Interner Fehler</translation>
    </message>
    <message>
        <source>Interrupted</source>
        <translation type="obsolete">Unterbrochen</translation>
    </message>
    <message>
        <source>Device Busy</source>
        <translation type="obsolete">Gerät beschäftigt</translation>
    </message>
    <message>
        <source>No Such Cart/Cut</source>
        <translation type="obsolete">Kein solcher Cart/Cut</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Neznámý</translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCM24</source>
        <translation type="unfinished">PCM24</translation>
    </message>
    <message>
        <source>Show Event Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>at</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Destination</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Origin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One Shot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trim Threshold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StartDate Offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EndDate Offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bit Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
